#!/usr/bin/perl

=head2  reload_ast

   Description:    Reloads asterisk
   Arguments:      None.
   Returns:        None.

=cut

sub reload_ast
{
	use strict;

	my $file = shift;
	my $ret = undef;
	my $mod_reload = '';
	my $ignore = 0;

	if (defined($file) && $file =~ m|^(/data/\d+)?/etc/asterisk/|)
	{
		if($file =~ m#/(agents|alsa|dahdi|iax|mgcp|oss|phone|sip|skinny|vpb|woomera|zapata).conf$#)
		{
			if($1 eq 'agents')
			{
				$mod_reload = "chan_agent.so";
			}
			elsif($1 eq 'iax')
			{
				$mod_reload = "chan_iax2.so";
			}
			elsif($1 eq 'zapata')
			{
				$mod_reload = "chan_dahdi.so";
			}
			else
			{
				$mod_reload = "chan_$1.so";
			}
		}
		elsif($file =~ m#/(adsi|indications|musiconhold).conf$#)
		{
			$mod_reload = "res_$1.so";
		}
		elsif($file =~ m#/(festival|ices|meetme|queues|rpt|voicemail|vm_companydir|vm_default).conf$#)
		{
			if($1 eq 'queues')
			{
				$mod_reload = "app_queue.so";
			}
			elsif($1 eq 'vm_companydir' or $1 eq 'vm_default')
			{
				$mod_reload = "app_voicemail.so";
			}
			else
			{
				$mod_reload = "app_$1.so";
			}
		}
		elsif($file =~ m#/(cdr|dnsmgr|enum|features|logger|manager|parking|rtp).conf$#)
		{
			if($1 eq 'parking')
			{
				$mod_reload = 'features';
			}
			else
			{
				$mod_reload = $1;
			}
		}
		elsif($file =~ m#/(cdr_odbc|cdr_pgsql|chan_dahdi|extensions).conf$#)
		{
			if($1 eq 'extensions')
			{
				$mod_reload = 'pbx_config.so';
			}
			else
			{
				$mod_reload = "$1.so";
			}
		}
		if($file =~ m#/asterisk-ices.xml$#)
		{
			$mod_reload = "app_ices.so";
		}
		elsif ($file =~ m^/fonality/|/extensions\.conf$^)
		{
			$mod_reload = "pbx_config.so";
		}
		elsif ($file =~ m^/(?:alerts|astwatch|pbxtra|woot|modprobe|tollrestriction|user_recordings|users)\.conf$|\.xml$^)
		{
			# ignore
			$ignore = 1;
		}
		elsif($file =~ m#/modules.conf$#)
		{
			$mod_reload = '';
		}
		elsif ($file =~ /\.conf$/)
		{
			# check if partial reload is supported
			my $chk = `/usr/sbin/asterisk -rx 'help dialplan reload'`;
			if($chk =~ /configfile/)
			{
				$mod_reload =  $file;
			}
		}
		if(!$ignore)
		{
			if($mod_reload ne '')
			{
				print "reload $mod_reload\n";
				#$ret = `/var/www/rpc/astreload $mod_reload`;
			}
			else
			{
				print "reload\n";
				#$ret = `/var/www/rpc/astreload`;
			}
		}
	}
	else
	{
		# no specific file given, reload all
		print "reload\n";
		#$ret = `/var/www/rpc/astreload`;
	}

	return $ret;
}

reload_ast("/etc/asterisk/sip.conf");

